@@ -13,7 +13,7 @@
 #' # getPMIDs(author="Yanhui Fan",dFrom=2007,dTo=2013,n=10)
 getPMIDs <-function(author,dFrom, dTo, n=50){
   eSearch <- "http://eutils.ncbi.nlm.nih.gov/entrez/eutils/esearch.fcgi?db=pubmed&term=" 
-  aL <- str_replace(author, " ", "+")
+  aL <- str_replace_all(author, " ", "+")
   aQ <- paste(aL, "[author]", sep = "")
   
   dQ <- ""
